References
----------
- http://elinux.org/Rpi_Low-level_peripherals#General_Purpose_Input.2FOutput_.28GPIO.29
- http://binerry.de/post/25787954149/pcd8544-library-for-raspberry-pi
- http://www.avdweb.nl/arduino/hardware-interfacing/nokia-5110-lcd.html
- http://www.raspberrypi.org/phpBB3/viewtopic.php?f=32&t=9814&start=100
- https://projects.drogon.net/raspberry-pi/wiringpi/pins/
- http://www.henningkarlsen.com/electronics/t_imageconverter_mono.php
- https://vimeo.com/41393421
- http://fritzing.org
- http://www.sitronix.com.tw/sitronix/product.nsf/Doc/ST7735?OpenDocument
- http://learn.adafruit.com/1-8-tft-display
- http://www.raspberrypi.org/phpBB3/viewtopic.php?t=28696&p=262909
- http://elinux.org/images/1/19/Passing_Time_With_SPI_Framebuffer_Driver.pdf
- http://www.flickr.com/photos/ngreatorex/7672743302/
- https://github.com/notro/fbtft
- https://github.com/rm-hull/st7735fb
- http://www.areinhardt.de/news/raspberry-pi-tft-display/
- http://www.whence.com/rpi/
- http://harizanov.com/product/1-8-tft-display-for-raspberry-pi/
- https://www.circuits.dk/everything-about-raspberry-gpio/
